#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_NEGATE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_NEGATE_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/simd/negate.hpp>

#endif
